@@ -1,8 +1,8 @@
 from six import python_2_unicode_compatible
-from ..mixins import ToJsonMixin, FromJsonMixin, ReadMixin, ListMixin, UpdateMixin
+from ..mixins import ToDictMixin, ToJsonMixin, FromJsonMixin, ListMixin, ReadMixin, UpdateMixin
 
 
-class QuickbooksBaseObject(ToJsonMixin, FromJsonMixin):
+class QuickbooksBaseObject(ToJsonMixin, FromJsonMixin, ToDictMixin):
     class_dict = {}
     list_dict = {}
     detail_dict = {}
@@ -25,7 +25,7 @@ class QuickbooksReadOnlyObject(QuickbooksBaseObject, ReadMixin, ListMixin):
 
 
 @python_2_unicode_compatible
-class MetaData:
+class MetaData(FromJsonMixin):
     def __init__(self):
         self.CreateTime = ""
         self.LastUpdatedTime = ""
@@ -66,7 +66,7 @@ class Address(QuickbooksBaseObject):
 
 
 @python_2_unicode_compatible
-class PhoneNumber(ToJsonMixin, FromJsonMixin):
+class PhoneNumber(ToJsonMixin, FromJsonMixin, ToDictMixin):
     def __init__(self):
         self.FreeFormNumber = ""
 
@@ -106,6 +106,7 @@ class Ref(QuickbooksBaseObject):
 @python_2_unicode_compatible
 class CustomField(QuickbooksBaseObject):
     def __init__(self):
+        self.DefinitionId = ""
         self.Type = ""
         self.Name = ""
         self.StringValue = ""
