@@ -1,6 +1,7 @@
 from six import python_2_unicode_compatible
 
-from quickbooks.objects.detailline import DetailLine, AccountBasedExpenseLine, ItemBasedExpenseLine
+from quickbooks.objects.detailline import DetailLine, AccountBasedExpenseLine, ItemBasedExpenseLine, \
+    TDSLine
 from .base import Ref, QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedTxnMixin, \
     LinkedTxn, Address
 from .tax import TxnTaxDetail
@@ -21,7 +22,7 @@ class Purchase(DeleteMixin, QuickbooksManagedObject, QuickbooksTransactionEntity
     For example, to create a transaction that sends a check to a vendor, create a Purchase object with PaymentType
     set to Check. To query Purchase transactions of a certain type, for example Check, submit the following to the
     query endpoint: SELECT * from Purchase where PaymentType='Check' You must specify an AccountRef for all purchases.
-    The TotalAmtattribute must add up to sum of Line.Amount attributes.
+    The TotalAmt attribute must add up to sum of Line.Amount attributes.
     """
     class_dict = {
         "AccountRef": Ref,
@@ -41,6 +42,7 @@ class Purchase(DeleteMixin, QuickbooksManagedObject, QuickbooksTransactionEntity
     detail_dict = {
         "AccountBasedExpenseLineDetail": AccountBasedExpenseLine,
         "ItemBasedExpenseLineDetail": ItemBasedExpenseLine,
+        "TDSLineDetail": TDSLine,
     }
 
     qbo_object_name = "Purchase"
