@@ -1,31 +1,15 @@
-import os
-import unittest
 from datetime import datetime
 
-from quickbooks.auth import Oauth1SessionManager
-from quickbooks.client import QuickBooks
 from quickbooks.objects.base import Ref
 from quickbooks.objects.bill import Bill
 from quickbooks.objects.detailline import AccountBasedExpenseLine, AccountBasedExpenseLineDetail
 from quickbooks.objects.vendor import Vendor
+from tests.integration.test_base import QuickbooksTestCase
 
 
-class BillTest(unittest.TestCase):
+class BillTest(QuickbooksTestCase):
     def setUp(self):
-        self.session_manager = Oauth1SessionManager(
-            sandbox=True,
-            consumer_key=os.environ.get('CONSUMER_KEY'),
-            consumer_secret=os.environ.get('CONSUMER_SECRET'),
-            access_token=os.environ.get('ACCESS_TOKEN'),
-            access_token_secret=os.environ.get('ACCESS_TOKEN_SECRET'),
-        )
-
-        self.qb_client = QuickBooks(
-            session_manager=self.session_manager,
-            sandbox=True,
-            company_id=os.environ.get('COMPANY_ID')
-        )
-
+        super(BillTest, self).setUp()
         self.account_number = datetime.now().strftime('%d%H%M')
         self.name = "Test Account {0}".format(self.account_number)
 
@@ -50,6 +34,6 @@ class BillTest(unittest.TestCase):
 
         query_bill = Bill.get(bill.Id, qb=self.qb_client)
 
-        self.assertEquals(query_bill.Id, bill.Id)
-        self.assertEquals(len(query_bill.Line), 1)
-        self.assertEquals(query_bill.Line[0].Amount, 200.0)
+        self.assertEqual(query_bill.Id, bill.Id)
+        self.assertEqual(len(query_bill.Line), 1)
+        self.assertEqual(query_bill.Line[0].Amount, 200.0)
