@@ -36,12 +36,12 @@ class ItemTest(QuickbooksTestCase):
 
         query_item = Item.get(item.Id, qb=self.qb_client)
 
-        self.assertEquals(query_item.Id, item.Id)
-        self.assertEquals(query_item.Name, self.name)
-        self.assertEquals(query_item.Type, "Inventory")
-        self.assertEquals(query_item.Sku, "SKU123123")
-        self.assertEquals(query_item.TrackQtyOnHand, True)
-        self.assertEquals(query_item.QtyOnHand, 10)
-        self.assertEquals(query_item.IncomeAccountRef.value, self.income_account.Id)
-        self.assertEquals(query_item.ExpenseAccountRef.value, self.expense_account.Id)
-        self.assertEquals(query_item.AssetAccountRef.value, self.asset_account.Id)
+        self.assertEqual(query_item.Id, item.Id)
+        self.assertEqual(query_item.Name, self.name)
+        self.assertEqual(query_item.Type, "Inventory")
+        self.assertEqual(query_item.Sku, "SKU123123")
+        self.assertEqual(query_item.TrackQtyOnHand, True)
+        self.assertEqual(query_item.QtyOnHand, 10)
+        self.assertEqual(query_item.IncomeAccountRef.value, self.income_account.Id)
+        self.assertEqual(query_item.ExpenseAccountRef.value, self.expense_account.Id)
+        self.assertEqual(query_item.AssetAccountRef.value, self.asset_account.Id)
