@@ -13,12 +13,12 @@ class PreferencesTest(QuickbooksTestCase):
     def test_get(self):
         preferences = Preferences.get(qb=self.qb_client)
 
-        self.assertEquals(preferences.Id, "1")
-        self.assertEquals(preferences.AccountingInfoPrefs.TaxYearMonth, "January")
-        self.assertEquals(preferences.ProductAndServicesPrefs.ForPurchase, True)
-        self.assertEquals(preferences.VendorAndPurchasesPrefs.BillableExpenseTracking, True)
-        self.assertEquals(preferences.TimeTrackingPrefs.WorkWeekStartDate, "Monday")
-        self.assertEquals(preferences.OtherPrefs.NameValue[0].Name, "SalesFormsPrefs.DefaultCustomerMessage")
+        self.assertEqual(preferences.Id, "1")
+        self.assertEqual(preferences.AccountingInfoPrefs.TaxYearMonth, "January")
+        self.assertEqual(preferences.ProductAndServicesPrefs.ForPurchase, True)
+        self.assertEqual(preferences.VendorAndPurchasesPrefs.BillableExpenseTracking, True)
+        self.assertEqual(preferences.TimeTrackingPrefs.WorkWeekStartDate, "Monday")
+        self.assertEqual(preferences.OtherPrefs.NameValue[0].Name, "SalesFormsPrefs.DefaultCustomerMessage")
 
     def test_update(self):
         preferences = Preferences.get(qb=self.qb_client)
@@ -28,4 +28,4 @@ class PreferencesTest(QuickbooksTestCase):
         preferences.save(qb=self.qb_client)
 
         preferences_updated = Preferences.get(qb=self.qb_client)
-        self.assertEquals(preferences_updated.EmailMessagesPrefs.EstimateMessage.Subject, subject)
+        self.assertEqual(preferences_updated.EmailMessagesPrefs.EstimateMessage.Subject, subject)
