@@ -6,5 +6,5 @@ class TaxRateTest(QuickbooksTestCase):
     def test_read(self):
         tax_rates = TaxRate.all(max_results=1, qb=self.qb_client)
 
-        self.assertEquals(len(tax_rates), 1)
+        self.assertEqual(len(tax_rates), 1)
 
