@@ -1,6 +1,6 @@
 import unittest
 
-
+from quickbooks import QuickBooks
 from quickbooks.objects.account import Account
 
 
@@ -9,7 +9,7 @@ class AccountTests(unittest.TestCase):
         account = Account()
         account.FullyQualifiedName = "test"
 
-        self.assertEquals(str(account), "test")
+        self.assertEqual(str(account), "test")
 
     def test_to_ref(self):
         account = Account()
@@ -18,6 +18,13 @@ class AccountTests(unittest.TestCase):
 
         ref = account.to_ref()
 
-        self.assertEquals(ref.name, "test")
-        self.assertEquals(ref.type, "Account")
-        self.assertEquals(ref.value, 12)
+        self.assertEqual(ref.name, "test")
+        self.assertEqual(ref.type, "Account")
+        self.assertEqual(ref.value, 12)
+
+    def test_valid_object_name(self):
+        account = Account()
+        client = QuickBooks()
+        result = client.isvalid_object_name(account.qbo_object_name)
+
+        self.assertTrue(result)
\ No newline at end of file
