@@ -1,5 +1,6 @@
 import unittest
 
+from quickbooks import QuickBooks
 from quickbooks.objects.payment import PaymentLine, Payment
 
 
@@ -8,7 +9,7 @@ class PaymentLineTests(unittest.TestCase):
         payment_line = PaymentLine()
         payment_line.Amount = 100
 
-        self.assertEquals(str(payment_line), "100")
+        self.assertEqual(str(payment_line), "100")
 
 
 class PaymentTests(unittest.TestCase):
@@ -16,4 +17,11 @@ class PaymentTests(unittest.TestCase):
         payment = Payment()
         payment.TotalAmt = 1000
 
-        self.assertEquals(str(payment), '1000')
+        self.assertEqual(str(payment), '1000')
+
+    def test_valid_object_name(self):
+        obj = Payment()
+        client = QuickBooks()
+        result = client.isvalid_object_name(obj.qbo_object_name)
+
+        self.assertTrue(result)
\ No newline at end of file
