@@ -9,7 +9,7 @@ class TaxCodeTests(unittest.TestCase):
         taxcode = TaxCode()
         taxcode.Name = "test"
 
-        self.assertEquals(str(taxcode), "test")
+        self.assertEqual(str(taxcode), "test")
 
     def test_valid_object_name(self):
         obj = TaxCode()
@@ -24,21 +24,21 @@ class TaxCodeTests(unittest.TestCase):
         taxcode.Name = "test"
 
         ref = taxcode.to_ref()
-        self.assertEquals(ref.name, "test")
-        self.assertEquals(ref.type, "TaxCode")
-        self.assertEquals(ref.value, 2)
+        self.assertEqual(ref.name, "test")
+        self.assertEqual(ref.type, "TaxCode")
+        self.assertEqual(ref.value, 2)
 
 
 class TaxRateDetailTests(unittest.TestCase):
     def test_init(self):
         tax_rate = TaxRateDetail()
 
-        self.assertEquals(tax_rate.TaxOrder, 0)
-        self.assertEquals(tax_rate.TaxTypeApplicable, "")
+        self.assertEqual(tax_rate.TaxOrder, 0)
+        self.assertEqual(tax_rate.TaxTypeApplicable, "")
 
 
 class TaxRateListTests(unittest.TestCase):
     def test_init(self):
         tax_rate_list = TaxRateList()
 
-        self.assertEquals(tax_rate_list.TaxRateDetail, [])
+        self.assertEqual(tax_rate_list.TaxRateDetail, [])
